@@ -129,7 +129,7 @@ int main(int argc, char *argv[]) {
 		}
 	}
 	if (aacEncoder_SetParam(handle, AACENC_SAMPLERATE, sample_rate) != AACENC_OK) {
-		fprintf(stderr, "Unable to set the AOT\n");
+		fprintf(stderr, "Unable to set the sample rate\n");
 		return 1;
 	}
 	if (aacEncoder_SetParam(handle, AACENC_CHANNELMODE, mode) != AACENC_OK) {
@@ -151,7 +151,7 @@ int main(int argc, char *argv[]) {
 			return 1;
 		}
 	}
-	if (aacEncoder_SetParam(handle, AACENC_TRANSMUX, 2) != AACENC_OK) {
+	if (aacEncoder_SetParam(handle, AACENC_TRANSMUX, TT_MP4_ADTS) != AACENC_OK) {
 		fprintf(stderr, "Unable to set the ADTS transmux\n");
 		return 1;
 	}
@@ -196,20 +196,17 @@ int main(int argc, char *argv[]) {
 			const uint8_t* in = &input_buf[2*i];
 			convert_buf[i] = in[0] | (in[1] << 8);
 		}
-		if (read <= 0) {
-			in_args.numInSamples = -1;
-		} else {
-			in_ptr = convert_buf;
-			in_size = read;
-			in_elem_size = 2;
+		in_ptr = convert_buf;
+		in_size = read;
+		in_elem_size = 2;
+
+		in_args.numInSamples = read <= 0 ? -1 : read/2;
+		in_buf.numBufs = 1;
+		in_buf.bufs = &in_ptr;
+		in_buf.bufferIdentifiers = &in_identifier;
+		in_buf.bufSizes = &in_size;
+		in_buf.bufElSizes = &in_elem_size;
 
-			in_args.numInSamples = read/2;
-			in_buf.numBufs = 1;
-			in_buf.bufs = &in_ptr;
-			in_buf.bufferIdentifiers = &in_identifier;
-			in_buf.bufSizes = &in_size;
-			in_buf.bufElSizes = &in_elem_size;
-		}
 		out_ptr = outbuf;
 		out_size = sizeof(outbuf);
 		out_elem_size = 1;
